"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = DocItemLayout;
var _react = _interopRequireDefault(require("react"));
var _themeCommon = require("@docusaurus/theme-common");
var _internal = require("@docusaurus/theme-common/internal");
var _DocBreadcrumbs = _interopRequireDefault(require("@theme/DocBreadcrumbs"));
var _Content = _interopRequireDefault(require("@theme/DocItem/Content"));
var _Footer = _interopRequireDefault(require("@theme/DocItem/Footer"));
var _Paginator = _interopRequireDefault(require("@theme/DocItem/Paginator"));
var _Desktop = _interopRequireDefault(require("@theme/DocItem/TOC/Desktop"));
var _Mobile = _interopRequireDefault(require("@theme/DocItem/TOC/Mobile"));
var _DocVersionBadge = _interopRequireDefault(require("@theme/DocVersionBadge"));
var _DocVersionBanner = _interopRequireDefault(require("@theme/DocVersionBanner"));
var _clsx = _interopRequireDefault(require("clsx"));
var _stylesModule = _interopRequireDefault(require("./styles.module.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */

/**
 * Decide if the toc should be rendered, on mobile or desktop viewports
 */
function useDocTOC() {
  const {
    frontMatter,
    toc
  } = (0, _internal.useDoc)();
  const windowSize = (0, _themeCommon.useWindowSize)();
  const hidden = frontMatter.hide_table_of_contents;
  const canRender = !hidden && toc.length > 0;
  const mobile = canRender ? <_Mobile.default /> : undefined;
  const desktop = canRender && (windowSize === "desktop" || windowSize === "ssr") ? <_Desktop.default /> : undefined;
  return {
    hidden,
    mobile,
    desktop
  };
}
function DocItemLayout({
  children
}) {
  const docTOC = useDocTOC();
  const {
    frontMatter: {
      api
    }
  } = (0, _internal.useDoc)();
  return <div className="row">
      <div className={(0, _clsx.default)("col", !docTOC.hidden && _stylesModule.default.docItemCol)}>
        <_DocVersionBanner.default />
        <div className={_stylesModule.default.docItemContainer}>
          <article>
            <_DocBreadcrumbs.default />
            <_DocVersionBadge.default />
            {docTOC.mobile}
            <_Content.default>{children}</_Content.default>
            <div className={(0, _clsx.default)("col", api ? "col--7" : "col--12")}>
              <_Footer.default />
            </div>
          </article>
          <div className={(0, _clsx.default)("col", api ? "col--7" : "col--12")}>
            <_Paginator.default />
          </div>
        </div>
      </div>
      {docTOC.desktop && <div className="col col--3">{docTOC.desktop}</div>}
    </div>;
}