"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ApiTabs;
var _react = _interopRequireWildcard(require("react"));
var _themeCommon = require("@docusaurus/theme-common");
var _useIsBrowser = _interopRequireDefault(require("@docusaurus/useIsBrowser"));
var _clsx = _interopRequireDefault(require("clsx"));
var _stylesModule = _interopRequireDefault(require("./styles.module.css"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/* ============================================================================
 * Copyright (c) Palo Alto Networks
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 * ========================================================================== */

const {
  useScrollPositionBlocker,
  useTabGroupChoice
} = require("@docusaurus/theme-common/internal");

// allowing customization

function isTabItem(comp) {
  return typeof comp.props.value !== "undefined";
}
function ApiTabsComponent(props) {
  var _ref, _children$find, _children$;
  const {
    lazy,
    block,
    defaultValue: defaultValueProp,
    values: valuesProp,
    groupId,
    className,
    title
  } = props;
  const children = _react.Children.map(props.children, child => {
    if ((0, _react.isValidElement)(child) && isTabItem(child)) {
      return child;
    } // child.type.name will give non-sensical values in prod because of
    // minification, but we assume it won't throw in prod.

    throw new Error(`Docusaurus error: Bad <Tabs> child <${
    // @ts-expect-error: guarding against unexpected cases
    typeof child.type === "string" ? child.type : child.type.name}>: all children of the <Tabs> component should be <TabItem>, and every <TabItem> should have a unique "value" prop.`);
  });
  if (!children || !children.length) {
    throw new Error("Docusaurus error: <Tabs> should have at least one <TabItem> child.");
  }
  const values = valuesProp !== null && valuesProp !== void 0 ? valuesProp :
  // We only pick keys that we recognize. MDX would inject some keys by default
  children.map(({
    props: {
      value,
      label,
      attributes
    }
  }) => ({
    value,
    label,
    attributes
  }));
  const dup = (0, _themeCommon.duplicates)(values, (a, b) => a.value === b.value);
  if (dup.length > 0) {
    throw new Error(`Docusaurus error: Duplicate values "${dup.map(a => a.value).join(", ")}" found in <Tabs>. Every value needs to be unique.`);
  } // When defaultValueProp is null, don't show a default tab

  const defaultValue = defaultValueProp === null ? defaultValueProp : (_ref = defaultValueProp !== null && defaultValueProp !== void 0 ? defaultValueProp : (_children$find = children.find(child => child.props.default)) === null || _children$find === void 0 ? void 0 : _children$find.props.value) !== null && _ref !== void 0 ? _ref : (_children$ = children[0]) === null || _children$ === void 0 ? void 0 : _children$.props.value;
  if (defaultValue !== null && !values.some(a => a.value === defaultValue)) {
    throw new Error(`Docusaurus error: The <Tabs> has a defaultValue "${defaultValue}" but none of its children has the corresponding value. Available values are: ${values.map(a => a.value).join(", ")}. If you intend to show no default tab, use defaultValue={null} instead.`);
  }
  const {
    tabGroupChoices,
    setTabGroupChoices
  } = useTabGroupChoice();
  const [selectedValue, setSelectedValue] = (0, _react.useState)(defaultValue);
  const tabRefs = [];
  const {
    blockElementScrollPositionUntilNextRender
  } = useScrollPositionBlocker();
  if (groupId != null) {
    const relevantTabGroupChoice = tabGroupChoices[groupId];
    if (relevantTabGroupChoice != null && relevantTabGroupChoice !== selectedValue && values.some(value => value.value === relevantTabGroupChoice)) {
      setSelectedValue(relevantTabGroupChoice);
    }
  }
  const handleTabChange = event => {
    const newTab = event.currentTarget;
    const newTabIndex = tabRefs.indexOf(newTab);
    const newTabValue = values[newTabIndex].value;
    if (newTabValue !== selectedValue) {
      blockElementScrollPositionUntilNextRender(newTab);
      setSelectedValue(newTabValue);
      if (groupId != null) {
        setTabGroupChoices(groupId, newTabValue);
      }
    }
  };
  const handleKeydown = event => {
    let focusElement = null;
    switch (event.key) {
      case "ArrowRight":
        {
          const nextTab = tabRefs.indexOf(event.currentTarget) + 1;
          focusElement = tabRefs[nextTab] || tabRefs[0];
          break;
        }
      case "ArrowLeft":
        {
          const prevTab = tabRefs.indexOf(event.currentTarget) - 1;
          focusElement = tabRefs[prevTab] || tabRefs[tabRefs.length - 1];
          break;
        }
      default:
        break;
    }
    if (focusElement) {
      focusElement.focus();
    }
  };
  const tabItemListContainerRef = (0, _react.useRef)(null);
  const [showTabArrows, setShowTabArrows] = (0, _react.useState)(false);
  (0, _react.useEffect)(() => {
    const resizeObserver = new ResizeObserver(entries => {
      for (let entry of entries) {
        const targetElement = entry.target;
        if (targetElement.offsetWidth < targetElement.scrollWidth) {
          setShowTabArrows(true);
        } else {
          setShowTabArrows(false);
        }
      }
    });
    if (tabItemListContainerRef.current) {
      resizeObserver.observe(tabItemListContainerRef.current);
    }
    return () => {
      resizeObserver.disconnect();
    };
  }, []);
  const handleRightClick = () => {
    if (tabItemListContainerRef.current) {
      tabItemListContainerRef.current.scrollLeft += 90;
    }
  };
  const handleLeftClick = () => {
    if (tabItemListContainerRef.current) {
      tabItemListContainerRef.current.scrollLeft -= 90;
    }
  };
  return <div className="tabs__container">
      <div className={_stylesModule.default.responseTabsTopSection}>
        <h3>{title !== null && title !== void 0 ? title : "Response"}</h3>
        <div className={_stylesModule.default.responseTabsContainer}>
          {showTabArrows && <button className={(0, _clsx.default)(_stylesModule.default.tabArrow, _stylesModule.default.tabArrowLeft)} onClick={handleLeftClick} />}
          <ul ref={tabItemListContainerRef} role="tablist" aria-orientation="horizontal" className={(0, _clsx.default)(_stylesModule.default.responseTabsListContainer, "tabs", {
          "tabs--block": block
        }, className)}>
            {values.map(({
            value,
            label,
            attributes
          }) => {
            var _attributes$className;
            const responseStatusStyle = parseInt(value) >= 400 ? _stylesModule.default.responseStatusDanger : parseInt(value) >= 200 && parseInt(value) < 300 ? _stylesModule.default.responseStatusSuccess : _stylesModule.default.responseStatusInfo;
            return <li role="tab" tabIndex={selectedValue === value ? 0 : -1} aria-selected={selectedValue === value} key={value} ref={tabControl => {
              if (tabControl) {
                tabRefs.push(tabControl);
              }
            }} onKeyDown={handleKeydown} onFocus={handleTabChange} onClick={handleTabChange} {...attributes} className={(0, _clsx.default)("tabs__item", _stylesModule.default.tabItem, (_attributes$className = attributes === null || attributes === void 0 ? void 0 : attributes.className) !== null && _attributes$className !== void 0 ? _attributes$className : "", responseStatusStyle, {
              [_stylesModule.default.active]: selectedValue === value
            })}>
                  <div className={_stylesModule.default.responseTabDot} />
                  {label !== null && label !== void 0 ? label : value}
                </li>;
          })}
          </ul>
          {showTabArrows && <button className={(0, _clsx.default)(_stylesModule.default.tabArrow, _stylesModule.default.tabArrowRight)} onClick={handleRightClick} />}
        </div>
      </div>
      <hr />
      {lazy ? (0, _react.cloneElement)(children.filter(tabItem => tabItem.props.value === selectedValue)[0], {
      className: (0, _clsx.default)("margin-vert--md", _stylesModule.default.responseSchemaContainer)
    }) : <div className={(0, _clsx.default)("margin-vert--md", _stylesModule.default.responseSchemaContainer)}>
          {children.map((tabItem, i) => (0, _react.cloneElement)(tabItem, {
        key: i,
        hidden: tabItem.props.value !== selectedValue
      }))}
        </div>}
    </div>;
}
function ApiTabs(props) {
  const isBrowser = (0, _useIsBrowser.default)();
  return <ApiTabsComponent // Remount tabs after hydration
  // Temporary fix for https://github.com/facebook/docusaurus/issues/5653
  key={String(isBrowser)} {...props} />;
}